==> cosec-spring-boot-starter-1.16.12-sources.jar: me/ahoo/cosec/spring/boot/starter/CoSecAutoConfiguration.kt <==
/*
 * Copyright [2021-present] [ahoo wang <ahoowang@qq.com> (https://github.com/Ahoo-Wang)].
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *      http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package me.ahoo.cosec.spring.boot.starter

import me.ahoo.cosec.serialization.CoSecModule
import me.ahoo.cosec.spring.boot.starter.policy.MatcherFactoryRegister
import org.springframework.boot.autoconfigure.AutoConfiguration
import org.springframework.boot.autoconfigure.condition.ConditionalOnMissingBean
import org.springframework.boot.context.properties.EnableConfigurationProperties
import org.springframework.context.ApplicationContext
import org.springframework.context.annotation.Bean

/**
 * CoSec AutoConfiguration .
 *
 * @author ahoo wang
 */
@AutoConfiguration
@ConditionalOnCoSecEnabled
@EnableConfigurationProperties(CoSecProperties::class)
class CoSecAutoConfiguration {

    @Bean
    @ConditionalOnMissingBean
    fun coSecModule(): CoSecModule {
        return CoSecModule()
    }

    @Bean
    fun matcherFactoryRegister(applicationContext: ApplicationContext): MatcherFactoryRegister {
        return MatcherFactoryRegister(applicationContext)
    }
}

==> cosec-spring-boot-starter-2.8.0-sources.jar: me/ahoo/cosec/spring/boot/starter/CoSecAutoConfiguration.kt <==
/*
 * Copyright [2021-present] [ahoo wang <ahoowang@qq.com> (https://github.com/Ahoo-Wang)].
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *      http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package me.ahoo.cosec.spring.boot.starter

import me.ahoo.cosec.serialization.CoSecModule
import me.ahoo.cosec.spring.boot.starter.policy.MatcherFactoryRegister
import org.springframework.boot.autoconfigure.AutoConfiguration
import org.springframework.boot.autoconfigure.condition.ConditionalOnMissingBean
import org.springframework.boot.autoconfigure.jackson.JacksonAutoConfiguration
import org.springframework.boot.context.properties.EnableConfigurationProperties
import org.springframework.context.ApplicationContext
import org.springframework.context.annotation.Bean

/**
 * CoSec AutoConfiguration .
 *
 * @author ahoo wang
 */
@ConditionalOnCoSecEnabled
@AutoConfiguration(before = [JacksonAutoConfiguration::class])
@EnableConfigurationProperties(CoSecProperties::class)
class CoSecAutoConfiguration {

    @Bean
    @ConditionalOnMissingBean
    fun coSecModule(): CoSecModule {
        return CoSecModule()
    }

    @Bean
    fun matcherFactoryRegister(applicationContext: ApplicationContext): MatcherFactoryRegister {
        return MatcherFactoryRegister(applicationContext)
    }
}
